@@ -17,15 +17,15 @@ import attrs
 from attrs import define, field
 import numpy as np
 from pathlib import Path
-import os
 import copy
 
 from floris.type_dec import (
+    NDArrayObject,
     floris_array_converter,
     NDArrayFloat
 )
 from floris.utilities import Vec3, load_yaml
-from floris.simulation import BaseClass
+from floris.simulation import BaseClass, State
 from floris.simulation import Turbine
 
 
@@ -49,8 +49,15 @@ class Farm(BaseClass):
 
     turbine_definitions: dict = field(init=False)
     yaw_angles: NDArrayFloat = field(init=False)
+    yaw_angles_sorted: NDArrayFloat = field(init=False)
     coordinates: List[Vec3] = field(init=False)
     hub_heights: NDArrayFloat = field(init=False)
+    hub_heights_sorted: NDArrayFloat = field(init=False, default=[])
+    turbine_fCts: tuple = field(init=False, default=[])
+    turbine_type_map_sorted: NDArrayObject = field(init=False, default=[])
+    rotor_diameters_sorted: NDArrayFloat = field(init=False, default=[])
+    TSRs_sorted: NDArrayFloat = field(init=False, default=[])
+    pPs_sorted: NDArrayFloat = field(init=False, default=[])
 
     @layout_x.validator
     def check_x(self, instance: attrs.Attribute, value: Any) -> None:
@@ -75,17 +82,30 @@ class Farm(BaseClass):
             if type(val) is str:
                 _floris_dir = Path(__file__).parent.parent
                 fname = _floris_dir / "turbine_library" / f"{val}.yaml"
-                if not os.path.isfile(fname):
+                if not Path.is_file(fname):
                     raise ValueError("User-selected turbine definition `{}` does not exist in pre-defined turbine library.".format(val))
                 self.turbine_definitions[i] = load_yaml(fname)
 
+                # This is a temporary block of code that catches that ref_density_cp_ct is not defined
+                # In the yaml file and forces it in
+                # A warning is issued letting the user know in future versions defining this value explicitly
+                # will be required 
+                if not 'ref_density_cp_ct' in self.turbine_definitions[i]:
+                    self.logger.warn("The value ref_density_cp_ct is not defined in the file: %s " % fname)
+                    self.logger.warn("This value is not the simulated air density but is the density at which the cp/ct curves are defined")
+                    self.logger.warn("In previous versions this was assumed to be 1.225")
+                    self.logger.warn("Future versions of FLORIS will give an error if this value is not explicitly defined")
+                    self.logger.warn("Currently this value is being set to the prior default value of 1.225")
+                    self.turbine_definitions[i]['ref_density_cp_ct'] = 1.225
+
     def initialize(self, sorted_indices):
         # Sort yaw angles from most upstream to most downstream wind turbine
-        self.yaw_angles = np.take_along_axis(
+        self.yaw_angles_sorted = np.take_along_axis(
             self.yaw_angles,
             sorted_indices[:, :, :, 0, 0],
             axis=2,
         )
+        self.state = State.INITIALIZED
 
     def construct_hub_heights(self):
         self.hub_heights = np.array([turb['hub_height'] for turb in self.turbine_definitions])
@@ -99,6 +119,9 @@ class Farm(BaseClass):
     def construc_turbine_pPs(self):
         self.pPs = np.array([turb['pP'] for turb in self.turbine_definitions])
 
+    def construc_turbine_ref_density_cp_cts(self):
+        self.ref_density_cp_cts = np.array([turb['ref_density_cp_ct'] for turb in self.turbine_definitions])
+
     def construct_turbine_map(self):
         self.turbine_map = [Turbine.from_dict(turb) for turb in self.turbine_definitions]
 
@@ -118,13 +141,13 @@ class Farm(BaseClass):
 
     def expand_farm_properties(self, n_wind_directions: int, n_wind_speeds: int, sorted_coord_indices):
         template_shape = np.ones_like(sorted_coord_indices)
-        self.hub_heights = np.take_along_axis(self.hub_heights * template_shape, sorted_coord_indices, axis=2)
-        self.rotor_diameters = np.take_along_axis(self.rotor_diameters * template_shape, sorted_coord_indices, axis=2)
-        self.TSRs = np.take_along_axis(self.TSRs * template_shape, sorted_coord_indices, axis=2)
-        self.pPs = np.take_along_axis(self.pPs * template_shape, sorted_coord_indices, axis=2)
-        self.turbine_type_names = [turb["turbine_type"] for turb in self.turbine_definitions]
-        self.turbine_type_map = np.take_along_axis(
-            np.reshape(self.turbine_type_names * n_wind_directions, np.shape(sorted_coord_indices)),
+        self.hub_heights_sorted = np.take_along_axis(self.hub_heights * template_shape, sorted_coord_indices, axis=2)
+        self.rotor_diameters_sorted = np.take_along_axis(self.rotor_diameters * template_shape, sorted_coord_indices, axis=2)
+        self.TSRs_sorted = np.take_along_axis(self.TSRs * template_shape, sorted_coord_indices, axis=2)
+        self.pPs_sorted = np.take_along_axis(self.pPs * template_shape, sorted_coord_indices, axis=2)
+        self.turbine_type_names_sorted = [turb["turbine_type"] for turb in self.turbine_definitions]
+        self.turbine_type_map_sorted = np.take_along_axis(
+            np.reshape(self.turbine_type_names_sorted * n_wind_directions, np.shape(sorted_coord_indices)),
             sorted_coord_indices,
             axis=2
         )
@@ -132,14 +155,16 @@ class Farm(BaseClass):
     def set_yaw_angles(self, n_wind_directions: int, n_wind_speeds: int):
         # TODO Is this just for initializing yaw angles to zero?
         self.yaw_angles = np.zeros((n_wind_directions, n_wind_speeds, self.n_turbines))
+        self.yaw_angles_sorted = np.zeros((n_wind_directions, n_wind_speeds, self.n_turbines))
 
     def finalize(self, unsorted_indices):
-        self.yaw_angles = np.take_along_axis(self.yaw_angles, unsorted_indices[:,:,:,0,0], axis=2)
-        self.hub_heights = np.take_along_axis(self.hub_heights , unsorted_indices[:,:,:,0,0], axis=2)
-        self.rotor_diameters = np.take_along_axis(self.rotor_diameters, unsorted_indices[:,:,:,0,0], axis=2)
-        self.TSRs = np.take_along_axis(self.TSRs, unsorted_indices[:,:,:,0,0], axis=2)
-        self.pPs = np.take_along_axis(self.pPs, unsorted_indices[:,:,:,0,0], axis=2)
-        self.turbine_type_map = np.take_along_axis(self.turbine_type_map, unsorted_indices[:,:,:,0,0], axis=2)
+        self.yaw_angles = np.take_along_axis(self.yaw_angles_sorted, unsorted_indices[:,:,:,0,0], axis=2)
+        self.hub_heights = np.take_along_axis(self.hub_heights_sorted, unsorted_indices[:,:,:,0,0], axis=2)
+        self.rotor_diameters = np.take_along_axis(self.rotor_diameters_sorted, unsorted_indices[:,:,:,0,0], axis=2)
+        self.TSRs = np.take_along_axis(self.TSRs_sorted, unsorted_indices[:,:,:,0,0], axis=2)
+        self.pPs = np.take_along_axis(self.pPs_sorted, unsorted_indices[:,:,:,0,0], axis=2)
+        self.turbine_type_map = np.take_along_axis(self.turbine_type_map_sorted, unsorted_indices[:,:,:,0,0], axis=2)
+        self.state.USED
 
     @property
     def n_turbines(self):
