@@ -20,26 +20,28 @@ import yaml
 from floris.utilities import load_yaml
 
 import floris.logging_manager as logging_manager
-from floris.type_dec import FromDictMixin
 from floris.simulation import (
+    BaseClass,
     Farm,
     WakeModelManager,
     FlowField,
-    Turbine,
     Grid,
     TurbineGrid,
     FlowFieldGrid,
     FlowFieldPlanarGrid,
+    State,
     sequential_solver,
     cc_solver,
+    turbopark_solver,
     full_flow_sequential_solver,
-    full_flow_cc_solver
+    full_flow_cc_solver,
+    full_flow_turbopark_solver,
 )
 from attrs import define, field
 
 
 @define
-class Floris(logging_manager.LoggerBase, FromDictMixin):
+class Floris(BaseClass):
     """
     Top-level class that describes a Floris model and initializes the
     simulation. Use the :py:class:`~.simulation.farm.Farm` attribute to
@@ -71,6 +73,7 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
         self.farm.construct_rotor_diameters()
         self.farm.construct_turbine_TSRs()
         self.farm.construc_turbine_pPs()
+        self.farm.construc_turbine_ref_density_cp_cts()
         self.farm.construct_coordinates()
         self.farm.set_yaw_angles(self.flow_field.n_wind_directions, self.flow_field.n_wind_speeds)
 
@@ -81,6 +84,7 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
                 wind_directions=self.flow_field.wind_directions,
                 wind_speeds=self.flow_field.wind_speeds,
                 grid_resolution=self.solver["turbine_grid_points"],
+                time_series=self.flow_field.time_series,
             )
         elif self.solver["type"] == "flow_field_grid":
             self.grid = FlowFieldGrid(
@@ -89,6 +93,7 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
                 wind_directions=self.flow_field.wind_directions,
                 wind_speeds=self.flow_field.wind_speeds,
                 grid_resolution=self.solver["flow_field_grid_points"],
+                time_series=self.flow_field.time_series,
             )
         elif self.solver["type"] == "flow_field_planar_grid":
             self.grid = FlowFieldPlanarGrid(
@@ -101,6 +106,7 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
                 grid_resolution=self.solver["flow_field_grid_points"],
                 x1_bounds=self.solver["flow_field_bounds"][0],
                 x2_bounds=self.solver["flow_field_bounds"][1],
+                time_series=self.flow_field.time_series,
             )
         else:
             raise ValueError(
@@ -121,10 +127,10 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
             self.logging["file"]["enable"],
             self.logging["file"]["level"],
         )
-    
 
     # @profile
-    def steady_state_atmospheric_condition(self):
+    def initialize_domain(self):
+        """Initialize solution space prior to wake calculations"""
 
         # Initialize field quanitities; doing this immediately prior to doing
         # the calculation step allows for manipulating inputs in a script
@@ -134,6 +140,12 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
         # Initialize farm quantities
         self.farm.initialize(self.grid.sorted_indices)
 
+        self.state.INITIALIZED
+
+    def steady_state_atmospheric_condition(self):
+        """Perform the steady-state wind farm wake calculations. Note that
+        initialize_domain() is required to be called before this function."""
+
         vel_model = self.wake.model_strings["velocity_model"]
 
         # <<interface>>
@@ -146,6 +158,13 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
                 self.grid,
                 self.wake
             )
+        elif vel_model=="turbopark":
+            elapsed_time = turbopark_solver(
+                self.farm,
+                self.flow_field,
+                self.grid,
+                self.wake
+            )
         else:
             elapsed_time = sequential_solver(
                 self.farm,
@@ -156,9 +175,7 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
         # end = time.time()
         # elapsed_time = end - start
 
-        self.grid.finalize()
-        self.flow_field.finalize(self.grid.unsorted_indices)
-        self.farm.finalize(self.grid.unsorted_indices)
+        self.finalize()
         return elapsed_time
 
     def solve_for_viz(self):
@@ -174,9 +191,17 @@ class Floris(logging_manager.LoggerBase, FromDictMixin):
 
         if vel_model=="cc":
             full_flow_cc_solver(self.farm, self.flow_field, self.grid, self.wake)
+        elif vel_model=="turbopark":
+            full_flow_turbopark_solver(self.farm, self.flow_field, self.grid, self.wake)
         else:
             full_flow_sequential_solver(self.farm, self.flow_field, self.grid, self.wake)
 
+    def finalize(self):
+        # Once the wake calculation is finished, unsort the values to match
+        # the user-supplied order of things.
+        self.flow_field.finalize(self.grid.unsorted_indices)
+        self.farm.finalize(self.grid.unsorted_indices)
+        self.state = State.USED
 
     ## I/O
 
