@@ -22,7 +22,7 @@ import attrs
 from attrs import define, field
 import numpy as np
 
-from floris.utilities import Vec3, rotate_coordinates_rel_west, cosd, sind
+from floris.utilities import Vec3, rotate_coordinates_rel_west
 from floris.type_dec import  (
     floris_float_type,
     floris_array_converter,
@@ -54,21 +54,28 @@ class Grid(ABC):
     Args:
         turbine_coordinates (`list[Vec3]`): The collection of turbine coordinate (`Vec3`) objects.
         reference_turbine_diameter (:py:obj:`float`): The reference turbine's rotor diameter.
-        grid_resolution (:py:obj:`int` | :py:obj:`Iterable(int,)`): Grid resolution specific to each grid type
+        grid_resolution (:py:obj:`int` | :py:obj:`Iterable(int,)`): Grid resolution specific to each grid type.
+        wind_directions (:py:obj:`NDArrayFloat`): Wind directions supplied by the user.
+        wind_speeds (:py:obj:`NDArrayFloat`): Wind speeds supplied by the user.
+        time_series (:py:obj:`bool`): True/false flag to indicate whether the supplied wind data is a time series.
     """
     turbine_coordinates: list[Vec3] = field()
     reference_turbine_diameter: float
     grid_resolution: int | Iterable = field()
     wind_directions: NDArrayFloat = field(converter=floris_array_converter)
     wind_speeds: NDArrayFloat = field(converter=floris_array_converter)
+    time_series: bool = field()
 
     n_turbines: int = field(init=False)
     n_wind_speeds: int = field(init=False)
     n_wind_directions: int = field(init=False)
     turbine_coordinates_array: NDArrayFloat = field(init=False)
-    x: NDArrayFloat = field(init=False)
-    y: NDArrayFloat = field(init=False)
-    z: NDArrayFloat = field(init=False)
+    x: NDArrayFloat = field(init=False, default=[])
+    y: NDArrayFloat = field(init=False, default=[])
+    z: NDArrayFloat = field(init=False, default=[])
+    x_sorted: NDArrayFloat = field(init=False)
+    y_sorted: NDArrayFloat = field(init=False)
+    z_sorted: NDArrayFloat = field(init=False)
 
     def __attrs_post_init__(self) -> None:
         self.turbine_coordinates_array = np.array([c.elements for c in self.turbine_coordinates])
@@ -85,7 +92,10 @@ class Grid(ABC):
     @wind_speeds.validator
     def wind_speeds_validator(self, instance: attrs.Attribute, value: NDArrayFloat) -> None:
         """Using the validator method to keep the `n_wind_speeds` attribute up to date."""
-        self.n_wind_speeds = value.size
+        if self.time_series:
+            self.n_wind_speeds = 1
+        else:
+            self.n_wind_speeds = value.size
 
     @wind_directions.validator
     def wind_directions_validator(self, instance: attrs.Attribute, value: NDArrayFloat) -> None:
@@ -112,11 +122,6 @@ class Grid(ABC):
     def set_grid(self) -> None:
         raise NotImplementedError("Grid.set_grid")
 
-    @abstractmethod
-    def finalize(self) -> None:
-        raise NotImplementedError("Grid.finalize")
-
-
 @define
 class TurbineGrid(Grid):
     """See `Grid` for more details.
@@ -164,11 +169,11 @@ class TurbineGrid(Grid):
 
         In a y-z plane on the rotor swept area, the -2 dimension is a column of points and the -1 dimension is the row number.
         So the following line prints the 0'th column of the the 0'th turbine's grid:
-        print(grid.y[0,0,0,0,:])
-        print(grid.z[0,0,0,0,:])
+        print(grid.y_sorted[0,0,0,0,:])
+        print(grid.z_sorted[0,0,0,0,:])
         And this line prints a single point
-        print(grid.y[0,0,0,0,0])
-        print(grid.z[0,0,0,0,0])
+        print(grid.y_sorted[0,0,0,0,0])
+        print(grid.z_sorted[0,0,0,0,0])
         Note that the x coordinates are all the same for the rotor plane.
 
         """
@@ -196,14 +201,20 @@ class TurbineGrid(Grid):
             ),
             dtype=floris_float_type
         )
-        # Calculate the radial distance from the center of the turbine rotor
-        disc_grid = np.linspace(
-            -1 * disc_area_radius,
-            disc_area_radius,
-            self.grid_resolution,
-            dtype=floris_float_type,
-            axis=1
-        )
+        # Calculate the radial distance from the center of the turbine rotor.
+        # If a grid resolution of 1 is selected, create a disc_grid of zeros, as
+        # np.linspace would just return the starting value of -1 * disc_area_radius
+        # which would place the point below the center of the rotor.
+        if self.grid_resolution == 1:
+            disc_grid = np.zeros((np.shape(disc_area_radius)[0], 1 ))
+        else:
+            disc_grid = np.linspace(
+                -1 * disc_area_radius,
+                disc_area_radius,
+                self.grid_resolution,
+                dtype=floris_float_type,
+                axis=1
+            )
         # Construct the turbine grids
         # Here, they are already rotated to the correct orientation for each wind direction
         _x = x[:, :, :, None, None] * template_grid
@@ -222,17 +233,13 @@ class TurbineGrid(Grid):
         self.unsorted_indices = self.sorted_indices.argsort(axis=2)
 
         # Put the turbines into the final arrays in their sorted order
-        self.x = np.take_along_axis(_x, self.sorted_indices, axis=2)
-        self.y = np.take_along_axis(_y, self.sorted_indices, axis=2)
-        self.z = np.take_along_axis(_z, self.sorted_indices, axis=2)
-
-    def finalize(self):
-        # Replace the turbines in their unsorted order so that
-        # we can report values in a sane way.
-        self.x = np.take_along_axis(self.x, self.unsorted_indices, axis=2)
-        self.y = np.take_along_axis(self.y, self.unsorted_indices, axis=2)
-        self.z = np.take_along_axis(self.z, self.unsorted_indices, axis=2)
+        self.x_sorted = np.take_along_axis(_x, self.sorted_indices, axis=2)
+        self.y_sorted = np.take_along_axis(_y, self.sorted_indices, axis=2)
+        self.z_sorted = np.take_along_axis(_z, self.sorted_indices, axis=2)
 
+        self.x = np.take_along_axis(self.x_sorted, self.unsorted_indices, axis=2)
+        self.y = np.take_along_axis(self.y_sorted, self.unsorted_indices, axis=2)
+        self.z = np.take_along_axis(self.z_sorted, self.unsorted_indices, axis=2)
 
 @define
 class FlowFieldGrid(Grid):
@@ -283,13 +290,9 @@ class FlowFieldGrid(Grid):
             indexing="ij"
         )
 
-        self.x = x_points[None, None, :, :, :]
-        self.y = y_points[None, None, :, :, :]
-        self.z = z_points[None, None, :, :, :]
-
-    def finalize(self):
-        pass
-
+        self.x_sorted = x_points[None, None, :, :, :]
+        self.y_sorted = y_points[None, None, :, :, :]
+        self.z_sorted = z_points[None, None, :, :, :]
 
 @define
 class FlowFieldPlanarGrid(Grid):
@@ -347,9 +350,9 @@ class FlowFieldPlanarGrid(Grid):
                 indexing="ij"
             )
 
-            self.x = x_points[None, None, :, :, :]
-            self.y = y_points[None, None, :, :, :]
-            self.z = z_points[None, None, :, :, :]
+            self.x_sorted = x_points[None, None, :, :, :]
+            self.y_sorted = y_points[None, None, :, :, :]
+            self.z_sorted = z_points[None, None, :, :, :]
 
         elif self.normal_vector == "x":  # Rules of thumb for cross plane
             if self.x1_bounds is None:
@@ -365,9 +368,9 @@ class FlowFieldPlanarGrid(Grid):
                 indexing="ij"
             )
 
-            self.x = x_points[None, None, :, :, :]
-            self.y = y_points[None, None, :, :, :]
-            self.z = z_points[None, None, :, :, :]
+            self.x_sorted = x_points[None, None, :, :, :]
+            self.y_sorted = y_points[None, None, :, :, :]
+            self.z_sorted = z_points[None, None, :, :, :]
 
         elif self.normal_vector == "y":  # Rules of thumb for y plane
             if self.x1_bounds is None:
@@ -383,9 +386,9 @@ class FlowFieldPlanarGrid(Grid):
                 indexing="ij"
             )
 
-            self.x = x_points[None, None, :, :, :]
-            self.y = y_points[None, None, :, :, :]
-            self.z = z_points[None, None, :, :, :]
+            self.x_sorted = x_points[None, None, :, :, :]
+            self.y_sorted = y_points[None, None, :, :, :]
+            self.z_sorted = z_points[None, None, :, :, :]
 
         # self.sorted_indices = self.x.argsort(axis=2)
         # self.unsorted_indices = self.sorted_indices.argsort(axis=2)
@@ -395,7 +398,7 @@ class FlowFieldPlanarGrid(Grid):
         # self.y = np.take_along_axis(self.y, self.sorted_indices, axis=2)
         # self.z = np.take_along_axis(self.z, self.sorted_indices, axis=2)
 
-    def finalize(self):
+    # def finalize(self):
         # sorted_indices = self.x.argsort(axis=2)
         # unsorted_indices = sorted_indices.argsort(axis=2)
 
@@ -416,7 +419,7 @@ class FlowFieldPlanarGrid(Grid):
 
         # self.x, self.y, self.z = self._rotated_grid(-1 * self.wind_directions, (x_center_of_rotation, y_center_of_rotation))
         # TODO figure out how to un-rotate grid for plotting after it has been solved
-        pass
+        # pass
 
     # def _rotated_grid(self, angle, center_of_rotation):
     #     """
