@@ -20,7 +20,7 @@ from floris.simulation import Farm
 from floris.simulation import FlowField
 from floris.simulation import Grid
 from floris.simulation import Turbine
-from floris.utilities import cosd, sind, tand
+from floris.utilities import cosd, sind
 
 
 @define
@@ -79,7 +79,6 @@ class GaussVelocityDeflection(BaseModel):
     dm: float = field(converter=float, default=1.0)
     eps_gain: float = field(converter=float, default=0.2)
     use_secondary_steering: bool = field(converter=bool, default=True)
-    model_string = "gauss"
 
     def prepare_function(
         self,
@@ -88,10 +87,10 @@ class GaussVelocityDeflection(BaseModel):
     ) -> Dict[str, Any]:
 
         kwargs = dict(
-            x=grid.x,
-            y=grid.y,
-            z=grid.z,
-            freestream_velocity=flow_field.u_initial,
+            x=grid.x_sorted,
+            y=grid.y_sorted,
+            z=grid.z_sorted,
+            freestream_velocity=flow_field.u_initial_sorted,
             wind_veer=flow_field.wind_veer,
         )
         return kwargs
@@ -343,6 +342,7 @@ def wake_added_yaw(
 def calculate_transverse_velocity(
     u_i,
     u_initial,
+    dudz_initial,
     delta_x,
     delta_y,
     z,
@@ -402,9 +402,6 @@ def calculate_transverse_velocity(
     lmda = D / 8
     kappa = 0.41
     lm = kappa * z / (1 + kappa * z / lmda)
-    # TODO: get this from the z input?
-    z_basis = np.linspace(np.min(z), np.max(z), np.shape(u_initial)[4])
-    dudz_initial = np.gradient(u_initial, z_basis, axis=4)
     nu = lm ** 2 * np.abs(dudz_initial)
 
     decay = eps ** 2 / (4 * nu * delta_x / Uinf + eps ** 2)   # This is the decay downstream
